";
-
+
echo "";
-
+
echo "";
}
@@ -142,9 +142,9 @@ foreach ($files AS $file) {
}
}
-foreach ($langstrings_3d AS $filename => $file)
+foreach ($langstrings_3d AS $filename => $file)
{
- foreach ($file AS $linenum => $value)
+ foreach ($file AS $linenum => $value)
{
$keys = array_keys($langstrings_full, $value);
if (count($keys)>1)
@@ -173,11 +173,11 @@ $sininstallandadmin='';
$sother='';
$count = 0;
-foreach ($dups as $string => $pages)
+foreach ($dups as $string => $pages)
{
$count++;
$s='';
-
+
// Keyword $string
if ($web) $s.="
";
if ($web) $s.="
";
@@ -188,32 +188,32 @@ foreach ($dups as $string => $pages)
if ($web) $s.="
";
if ($web) $s.="
";
if (! $web) $s.= ' : ';
-
+
// Loop on each files keyword was found
$duplicateinsamefile=0;
$inmain=0;
$inadmin=0;
- foreach ($pages AS $file => $lines)
+ foreach ($pages AS $file => $lines)
{
if ($file == 'main.lang') { $inmain=1; $inadmin=0; }
if ($file == 'admin.lang' && ! $inmain) { $inadmin=1; }
-
+
$s.=$file." ";
-
+
// Loop on each line keword was found into file.
$listoffilesforthisentry=array();
- foreach ($lines as $line => $translatedvalue)
+ foreach ($lines as $line => $translatedvalue)
{
if (! empty($listoffilesforthisentry[$file])) $duplicateinsamefile=1;
$listoffilesforthisentry[$file]=1;
-
+
$s.= "(".$line." - ".htmlentities($translatedvalue).") ";
}
if ($web) $s.=" ";
}
if ($web) $s.="
";
$s.="\n";
-
+
if ($duplicateinsamefile) $sduplicateinsamefile .= $s;
else if ($inmain) $sinmainandother .= $s;
else if ($inadmin) $sininstallandadmin .= $s;
@@ -252,7 +252,7 @@ if ($web)
if ((! empty($_REQUEST['unused']) && $_REQUEST['unused'] == 'true') || (isset($argv[1]) && $argv[1]=='unused=true'))
{
print "***** Strings in en_US that are never used:\n";
-
+
$unused=array();
foreach ($langstrings_dist AS $value => $line)
{
@@ -288,7 +288,7 @@ if ((! empty($_REQUEST['unused']) && $_REQUEST['unused'] == 'true') || (isset($a
if (preg_match('/^JuridicalStatus/', $value)) $qualifiedforclean=0;
if (preg_match('/^CalcMode/', $value)) $qualifiedforclean=0;
if (preg_match('/^newLT/', $value)) $qualifiedforclean=0;
- if (preg_match('/^LT\d/', $value)) $qualifiedforclean=0;
+ if (preg_match('/^LT[0-9]/', $value)) $qualifiedforclean=0;
if (preg_match('/^TypeContact_contrat_/', $value)) $qualifiedforclean=0;
if (preg_match('/^ErrorPriceExpression/', $value)) $qualifiedforclean=0;
if (preg_match('/^Language_/', $value)) $qualifiedforclean=0;
@@ -315,7 +315,7 @@ if ((! empty($_REQUEST['unused']) && $_REQUEST['unused'] == 'true') || (isset($a
// orders
if (preg_match('/^OrderSource/', $value)) $qualifiedforclean=0;
if (preg_match('/^TypeContact_/', $value)) $qualifiedforclean=0;
- // other.lang
+ // other.lang
if (preg_match('/^Notify_/', $value)) $qualifiedforclean=0;
if (preg_match('/^PredefinedMail/', $value)) $qualifiedforclean=0;
if (preg_match('/^DemoCompany/', $value)) $qualifiedforclean=0;
@@ -336,17 +336,17 @@ if ((! empty($_REQUEST['unused']) && $_REQUEST['unused'] == 'true') || (isset($a
if (preg_match('/OppStatus/', $value)) $qualifiedforclean=0;
if (preg_match('/AvailabilityType/', $value)) $qualifiedforclean=0;
if (preg_match('/CardProduct/', $value)) $qualifiedforclean=0;
-
+
if (preg_match('/sms/i', $value)) $qualifiedforclean=0;
if (preg_match('/TF_/i', $value)) $qualifiedforclean=0;
if (preg_match('/WithBankUsing/i', $value)) $qualifiedforclean=0;
if (preg_match('/descWORKFLOW_/i', $value)) $qualifiedforclean=0;
-
+
if (! $qualifiedforclean)
{
- continue;
+ continue;
}
-
+
//$search = '\'trans("'.$value.'")\'';
$search = '-e "\''.$value.'\'" -e \'"'.$value.'"\' -e "('.$value.')" -e "('.$value.',"';
$string = 'grep -R -m 1 -F --exclude=includes/* --include=*.php '.$search.' '.$htdocs.'* '.$scripts.'*';
@@ -356,7 +356,7 @@ if ((! empty($_REQUEST['unused']) && $_REQUEST['unused'] == 'true') || (isset($a
$unused[$value] = $line;
echo $line; // $trad contains the \n
}
- else
+ else
{
unset($output);
//print 'X'.$output.'Y';
@@ -364,7 +364,7 @@ if ((! empty($_REQUEST['unused']) && $_REQUEST['unused'] == 'true') || (isset($a
}
if (empty($unused)) print "No string not used found.\n";
- else
+ else
{
$filetosave='/tmp/'.($argv[2]?$argv[2]:"").'notused.lang';
print "Strings in en_US that are never used are saved into file ".$filetosave.":\n";
diff --git a/htdocs/compta/tva/index.php b/htdocs/compta/tva/index.php
index 618ba11a37e..89accf57492 100644
--- a/htdocs/compta/tva/index.php
+++ b/htdocs/compta/tva/index.php
@@ -117,7 +117,7 @@ $textprevyear="".img_previo
$textnextyear=" ".img_next($langs->trans("Next"), 'class="valignbottom"')."";
print $conf->dol_optimize_smallscreen;
-print load_fiche_titre($langs->trans("VAT"), $textprevyear." ".$langs->trans("Year")." ".$year_start." ".$textnextyear, 'title_accountancy.png');
+print load_fiche_titre($langs->transcountry("VAT", $mysoc->country_code), $textprevyear." ".$langs->trans("Year")." ".$year_start." ".$textnextyear, 'title_accountancy.png');
print $langs->trans("VATReportBuildWithOptionDefinedInModule").' ';
print '('.$langs->trans("TaxModuleSetupToModifyRules",DOL_URL_ROOT.'/admin/taxes.php').') ';
@@ -263,18 +263,18 @@ if (! empty($conf->global->MAIN_FEATURES_LEVEL))
print "
";
print '
' . $langs->trans("VATDue") . '
'; // need to add translation
- print '
' . price(price2num($total, 1)) . '
';
+ print '
' . price(price2num($total, 'MT')) . '
';
print "
\n";
print "
";
print '
' . $langs->trans("VATPaid") . '
';
- print '
' . price(price2num($obj->mm, 1)) . "
\n";
+ print '
' . price(price2num($obj->mm, 'MT')) . "
\n";
print "
\n";
$restopay = $total - $obj->mm;
print "
";
print '
' . $langs->trans("VATRestopay") . '
'; // need to add translation
- print '
' . price(price2num($restopay, 1)) . '
';
+ print '
' . price(price2num($restopay, 'MT')) . '
';
print "
\n";
print '';
diff --git a/htdocs/core/class/html.form.class.php b/htdocs/core/class/html.form.class.php
index 06736ba5c5f..27115d12eb7 100644
--- a/htdocs/core/class/html.form.class.php
+++ b/htdocs/core/class/html.form.class.php
@@ -4417,7 +4417,7 @@ class Form
dol_syslog(__METHOD__, LOG_DEBUG);
- $sql = "SELECT DISTINCT t.rowid, t.code, t.taux, t.recuperableonly";
+ $sql = "SELECT DISTINCT t.rowid, t.code, t.taux, t.localtax1, t.localtax1_type, t.localtax2, t.localtax2_type, t.recuperableonly";
$sql.= " FROM ".MAIN_DB_PREFIX."c_tva as t, ".MAIN_DB_PREFIX."c_country as c";
$sql.= " WHERE t.fk_pays = c.rowid";
$sql.= " AND t.active > 0";
@@ -4436,8 +4436,20 @@ class Form
$this->cache_vatrates[$i]['rowid'] = $obj->rowid;
$this->cache_vatrates[$i]['code'] = $obj->code;
$this->cache_vatrates[$i]['txtva'] = $obj->taux;
- $this->cache_vatrates[$i]['libtva'] = $obj->taux.'%'.($obj->code?' ('.$obj->code.')':''); // Label must contains only 0-9 , . % or *
$this->cache_vatrates[$i]['nprtva'] = $obj->recuperableonly;
+ $this->cache_vatrates[$i]['localtax1'] = $obj->localtax1;
+ $this->cache_vatrates[$i]['localtax1_type'] = $obj->localtax1_type;
+ $this->cache_vatrates[$i]['localtax2'] = $obj->localtax2;
+ $this->cache_vatrates[$i]['localtax2_type'] = $obj->localtax1_type;
+
+ $this->cache_vatrates[$i]['label'] = $obj->taux.'%'.($obj->code?' ('.$obj->code.')':''); // Label must contains only 0-9 , . % or *
+ $this->cache_vatrates[$i]['labelallrates'] = $obj->taux.'/'.($obj->localtax1?$obj->localtax1:'0').'/'.($obj->localtax2?$obj->localtax2:'0').($obj->code?' ('.$obj->code.')':''); // Must never be used as key, only label
+ $positiverates='';
+ if ($obj->taux) $positiverates.=($positiverates?'/':'').$obj->taux;
+ if ($obj->localtax1) $positiverates.=($positiverates?'/':'').$obj->localtax1;
+ if ($obj->localtax2) $positiverates.=($positiverates?'/':'').$obj->localtax2;
+ if (empty($positiverates)) $positiverates='0';
+ $this->cache_vatrates[$i]['labelpositiverates'] = $positiverates.($obj->code?' ('.$obj->code.')':''); // Must never be used as key, only label
}
return $num;
@@ -4611,7 +4623,16 @@ class Form
$selectedfound=true;
}
}
- $return.= '>'.vatrate($rate['libtva']);
+ $return.= '>';
+ //if (! empty($conf->global->MAIN_VAT_SHOW_POSITIVE_RATES))
+ if ($mysoc->country_code == 'IN' || ! empty($conf->global->MAIN_VAT_LABEL_IS_POSITIVE_RATES))
+ {
+ $return.= $rate['labelpositiverates'];
+ }
+ else
+ {
+ $return.= vatrate($rate['label']);
+ }
//$return.=($rate['code']?' '.$rate['code']:'');
$return.= (empty($rate['code']) && $rate['nprtva']) ? ' *': ''; // We show the * (old behaviour only if new vat code is not used)
diff --git a/htdocs/core/menus/standard/eldy.lib.php b/htdocs/core/menus/standard/eldy.lib.php
index 2fcf1fa4ff2..530be07da39 100644
--- a/htdocs/core/menus/standard/eldy.lib.php
+++ b/htdocs/core/menus/standard/eldy.lib.php
@@ -871,7 +871,7 @@ function print_left_eldy_menu($db,$menu_array_before,$menu_array_after,&$tabMenu
// VAT
if (empty($conf->global->TAX_DISABLE_VAT_MENUS))
{
- $newmenu->add("/compta/tva/index.php?leftmenu=tax_vat&mainmenu=accountancy",$langs->trans("VAT"),1,$user->rights->tax->charges->lire, '', $mainmenu, 'tax_vat');
+ $newmenu->add("/compta/tva/index.php?leftmenu=tax_vat&mainmenu=accountancy",$langs->transcountry("VAT", $mysoc->country_code),1,$user->rights->tax->charges->lire, '', $mainmenu, 'tax_vat');
if ($usemenuhider || empty($leftmenu) || preg_match('/^tax_vat/i',$leftmenu)) $newmenu->add("/compta/tva/card.php?leftmenu=tax_vat&action=create",$langs->trans("New"),2,$user->rights->tax->charges->creer);
if ($usemenuhider || empty($leftmenu) || preg_match('/^tax_vat/i',$leftmenu)) $newmenu->add("/compta/tva/reglement.php?leftmenu=tax_vat",$langs->trans("List"),2,$user->rights->tax->charges->lire);
if ($usemenuhider || empty($leftmenu) || preg_match('/^tax_vat/i',$leftmenu)) $newmenu->add("/compta/tva/clients.php?leftmenu=tax_vat", $langs->trans("ReportByCustomers"), 2, $user->rights->tax->charges->lire);
diff --git a/htdocs/langs/en_US/compta.lang b/htdocs/langs/en_US/compta.lang
index 79ad6cfd628..4c6dc5bf169 100644
--- a/htdocs/langs/en_US/compta.lang
+++ b/htdocs/langs/en_US/compta.lang
@@ -30,18 +30,34 @@ Piece=Accounting Doc.
AmountHTVATRealReceived=Net collected
AmountHTVATRealPaid=Net paid
VATToPay=VAT sells
-VATReceived=VAT received
-VATToCollect=VAT purchases
-VATSummary=VAT Balance
-LT2SummaryES=IRPF Balance
+VATReceived=Tax received
+VATToCollect=Tax purchases
+VATSummary=Tax Balance
+VATPaid=Tax paid
+LT1Summary=Tax 2 summary
+LT2Summary=Tax 3 summary
LT1SummaryES=RE Balance
-VATPaid=VAT paid
-LT2PaidES=IRPF Paid
+LT2SummaryES=IRPF Balance
+LT1SummaryIN=CGST Balance
+LT2SummaryIN=SGST Balance
+LT1Paid=Tax 2 paid
+LT2Paid=Tax 3 paid
LT1PaidES=RE Paid
-LT2CustomerES=IRPF sales
-LT2SupplierES=IRPF purchases
+LT2PaidES=IRPF Paid
+LT1PaidIN=CGST Paid
+LT2PaidIN=SGST Paid
+LT1Customer=Tax 2 sales
+LT1Supplier=Tax 2 purchases
LT1CustomerES=RE sales
LT1SupplierES=RE purchases
+LT1CustomerIN=CGST sales
+LT1SupplierIN=CGST purchases
+LT2Customer=Tax 3 sales
+LT2Supplier=Tax 3 purchases
+LT2CustomerES=IRPF sales
+LT2SupplierES=IRPF purchases
+LT2CustomerIN=SGST sales
+LT2SupplierIN=SGST purchases
VATCollected=VAT collected
ToPay=To pay
SpecialExpensesArea=Area for all special payments
diff --git a/htdocs/langs/en_US/main.lang b/htdocs/langs/en_US/main.lang
index ff874d2fc1b..4f6926b4aed 100644
--- a/htdocs/langs/en_US/main.lang
+++ b/htdocs/langs/en_US/main.lang
@@ -356,17 +356,26 @@ Totalforthispage=Total for this page
TotalTTC=Total (inc. tax)
TotalTTCToYourCredit=Total (inc. tax) to your credit
TotalVAT=Total tax
+TotalVATIN=Total IGST
TotalLT1=Total tax 2
TotalLT2=Total tax 3
TotalLT1ES=Total RE
TotalLT2ES=Total IRPF
+TotalLT1IN=Total CGST
+TotalLT2IN=Total SGST
HT=Net of tax
TTC=Inc. tax
INCT=Inc. all taxes
VAT=Sales tax
+VATIN=IGST
VATs=Sales taxes
+VATINs=IGST taxes
+LT1=Sales tax 2
+LT2=Sales tax 3
LT1ES=RE
LT2ES=IRPF
+LT1IN=CGST
+LT2IN=SGST
VATRate=Tax Rate
Average=Average
Sum=Sum
diff --git a/htdocs/langs/en_US/modulebuilder.lang b/htdocs/langs/en_US/modulebuilder.lang
index a3ba8a7455b..063e1c8d332 100644
--- a/htdocs/langs/en_US/modulebuilder.lang
+++ b/htdocs/langs/en_US/modulebuilder.lang
@@ -51,6 +51,7 @@ WidgetFile=Widget file
ReadmeFile=Readme file
ChangeLog=ChangeLog file
SqlFile=Sql file
+SqlFileExtraFields=Sql file for complementary attributes
SqlFileKey=Sql file for keys
AnObjectAlreadyExistWithThisNameAndDiffCase=An object already exists with this name and a different case
UseAsciiDocFormat=You can use Markdown format, but it is recommanded to use Asciidoc format (Comparison between .md and .asciidoc: http://asciidoctor.org/docs/user-manual/#compared-to-markdown)
\ No newline at end of file
diff --git a/htdocs/langs/en_US/website.lang b/htdocs/langs/en_US/website.lang
index efae27e68dd..82d0022b1f9 100644
--- a/htdocs/langs/en_US/website.lang
+++ b/htdocs/langs/en_US/website.lang
@@ -12,7 +12,8 @@ MediaFiles=Media library
EditCss=Edit Style/CSS or HTML header
EditMenu=Edit menu
EditPageMeta=Edit Meta
-EditPageContent=Edit Content
+EditPageSource=Edit HTML Source
+EditPageContent=Edit with CKEditor
Website=Web site
Webpage=Web page/container
AddPage=Add page/container
@@ -33,7 +34,8 @@ PreviewSiteServedByDolibarr=Preview %s in a new tab.
The %s will be serve
VirtualHostUrlNotDefined=URL of the virtual host served by external web server not defined
NoPageYet=No pages yet
SyntaxHelp=Help on code syntax
-YouCanEditHtmlSource=You can edit HTML source code using the "Source" button in editor. You can also include PHP code into this source using tags <?php ?>. The following global variables are available: $conf, $langs, $db, $mysoc, $user, $website.
You can also include content of another Page/Container with the following syntax: <?php dolIncludeHtmlContent($websitekey.'/contentaliastoinclude.php'); ?>
To include a link to download a file stored into the documents/medias directory, use syntax: <a href="/document.php?modulepart=medias&file=filename.ext">.
+YouCanEditHtmlSourceckeditor=You can edit HTML source code using the "Source" button in editor.
+YouCanEditHtmlSource=You can include PHP code into this source using tags <?php ?>. The following global variables are available: $conf, $langs, $db, $mysoc, $user, $website.
You can also include content of another Page/Container with the following syntax: <?php dolIncludeHtmlContent($websitekey.'/contentaliastoinclude.php'); ?>
To include a link to download a file stored into the documents/medias directory, use syntax: <a href="/document.php?modulepart=medias&file=filename.ext">.
ClonePage=Clone page/container
CloneSite=Clone site
ConfirmClonePage=Please enter code/alias of new page and if it is a translation of the cloned page.
diff --git a/htdocs/modulebuilder/index.php b/htdocs/modulebuilder/index.php
index ab898458198..f6eea45003d 100644
--- a/htdocs/modulebuilder/index.php
+++ b/htdocs/modulebuilder/index.php
@@ -110,8 +110,9 @@ if ($dirins && $action == 'initmodule' && $modulename)
dol_delete_file($destdir.'/myobject_card.php');
dol_delete_file($destdir.'/myobject_list.php');
dol_delete_file($destdir.'/test/phpunit/MyObjectTest.php');
- dol_delete_file($destdir.'/sql/llx_myobject.key.sql');
dol_delete_file($destdir.'/sql/llx_myobject.sql');
+ dol_delete_file($destdir.'/sql/llx_myobject_extrafields.sql');
+ dol_delete_file($destdir.'/sql/llx_myobject.key.sql');
dol_delete_file($destdir.'/scripts/myobject.php');
dol_delete_file($destdir.'/img/object_myobject.png');
dol_delete_file($destdir.'/class/myobject.class.php');
@@ -189,9 +190,10 @@ if ($dirins && $action == 'initobject' && $module && $objectname)
'myobject_card.php'=>strtolower($objectname).'_card.php',
'myobject_list.php'=>strtolower($objectname).'_list.php',
'test/phpunit/MyObjectTest.php'=>'test/phpunit/'.$objectname.'Test.php',
- 'sql/llx_myobject.key.sql'=>'sql/llx_'.strtolower($objectname).'.key.sql',
'sql/llx_myobject.sql'=>'sql/llx_'.strtolower($objectname).'.sql',
- 'scripts/myobject.php'=>'scripts/'.strtolower($objectname).'.php',
+ 'sql/llx_myobject_extrafields.sql'=>'sql/llx_'.strtolower($objectname).'_extrafields.sql',
+ 'sql/llx_myobject.key.sql'=>'sql/llx_'.strtolower($objectname).'.key.sql',
+ 'scripts/myobject.php'=>'scripts/'.strtolower($objectname).'.php',
'img/object_myobject.png'=>'img/object_'.strtolower($objectname).'.png',
'class/myobject.class.php'=>'class/'.strtolower($objectname).'.class.php',
'class/api_myobject.class.php'=>'class/api_'.strtolower($objectname).'.class.php',
@@ -377,9 +379,10 @@ if ($dirins && $action == 'confirm_deleteobject' && $objectname)
'myobject_card.php'=>strtolower($objectname).'_card.php',
'myobject_list.php'=>strtolower($objectname).'_list.php',
'test/phpunit/MyObjectTest.php'=>'test/phpunit/'.$objectname.'Test.php',
- 'sql/llx_myobject.key.sql'=>'sql/llx_'.strtolower($objectname).'.key.sql',
'sql/llx_myobject.sql'=>'sql/llx_'.strtolower($objectname).'.sql',
- 'scripts/myobject.php'=>'scripts/'.strtolower($objectname).'.php',
+ 'sql/llx_myobject_extrafields.sql'=>'sql/llx_'.strtolower($objectname).'_extrafields.sql',
+ 'sql/llx_myobject.key.sql'=>'sql/llx_'.strtolower($objectname).'.key.sql',
+ 'scripts/myobject.php'=>'scripts/'.strtolower($objectname).'.php',
'img/object_myobject.png'=>'img/object_'.strtolower($objectname).'.png',
'class/myobject.class.php'=>'class/'.strtolower($objectname).'.class.php',
'class/api_myobject.class.php'=>'class/api_'.strtolower($objectname).'.class.php',
@@ -423,6 +426,7 @@ if ($dirins && $action == 'confirm_deleteproperty' && $propertykey)
// File of sql
$fileforsql = $dirins.'/'.$modulelowercase.'/sql/'.$objectlowercase.'.sql';
+ $fileforsqlextra = $dirins.'/'.$modulelowercase.'/sql/'.$objectlowercase.'_extrafields.sql';
$fileforsqlkey = $dirins.'/'.$modulelowercase.'/sql/'.$objectlowercase.'.key.sql';
@@ -1195,6 +1199,7 @@ elseif (! empty($module))
$pathtolist = strtolower($module).'/'.strtolower($tabobj).'_list.php';
$pathtocard = strtolower($module).'/'.strtolower($tabobj).'_card.php';
$pathtosql = strtolower($module).'/sql/llx_'.strtolower($tabobj).'.sql';
+ $pathtosqlextra = strtolower($module).'/sql/llx_'.strtolower($tabobj).'_extrafields.sql';
$pathtosqlkey = strtolower($module).'/sql/llx_'.strtolower($tabobj).'.key.sql';
print '
';
diff --git a/htdocs/modulebuilder/template/sql/llx_myobject_extrafields.sql b/htdocs/modulebuilder/template/sql/llx_myobject_extrafields.sql
new file mode 100644
index 00000000000..72c672a92f8
--- /dev/null
+++ b/htdocs/modulebuilder/template/sql/llx_myobject_extrafields.sql
@@ -0,0 +1,23 @@
+-- Copyright (C) ---Put here your own copyright and developer email---
+--
+-- This program is free software; you can redistribute it and/or modify
+-- it under the terms of the GNU General Public License as published by
+-- the Free Software Foundation; either version 3 of the License, or
+-- (at your option) any later version.
+--
+-- This program is distributed in the hope that it will be useful,
+-- but WITHOUT ANY WARRANTY; without even the implied warranty of
+-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+-- GNU General Public License for more details.
+--
+-- You should have received a copy of the GNU General Public License
+-- along with this program. If not, see .
+
+create table llx_myobject_extrafields
+(
+ rowid integer AUTO_INCREMENT PRIMARY KEY,
+ tms timestamp,
+ fk_object integer NOT NULL,
+ import_key varchar(14) -- import key
+) ENGINE=innodb;
+
diff --git a/htdocs/websites/index.php b/htdocs/websites/index.php
index f9519ee4cf0..d692295d2a5 100644
--- a/htdocs/websites/index.php
+++ b/htdocs/websites/index.php
@@ -101,6 +101,7 @@ if (GETPOST('editcss')) { $action='editcss'; }
if (GETPOST('editmenu')) { $action='editmenu'; }
if (GETPOST('setashome')) { $action='setashome'; }
if (GETPOST('editmeta')) { $action='editmeta'; }
+if (GETPOST('editsource')) { $action='editsource'; }
if (GETPOST('editcontent')) { $action='editcontent'; }
if (GETPOST('createfromclone')) { $action='createfromclone'; }
if (GETPOST('createpagefromclone')) { $action='createpagefromclone'; }
@@ -463,12 +464,12 @@ if ($action == 'updatemeta')
if (! $result) setEventMessages('Failed to write file '.$filealias, null, 'errors');
// Now create the .tpl file (duplicate code with actions updatecontent but we need this to save new header)
dol_syslog("We regenerate the tpl page filetpl=".$filetpl);
dol_delete_file($filetpl);
// TODO Same code than into updatecontent
$tplcontent ='';
$tplcontent.= "fetch(0, $website);
@@ -600,7 +601,7 @@ if (($action == 'updatecontent' || $action == 'confirm_createpagefromclone')
if (! $error && $res > 0)
{
- if ($action == 'updatecontent')
+ if ($action == 'updatesource' || $action == 'updatecontent')
{
$db->begin();
@@ -777,6 +778,10 @@ if ($action == 'editmeta')
{
print '';
}
+if ($action == 'editsource')
+{
+ print '';
+}
if ($action == 'editcontent')
{
print '';
@@ -789,7 +794,7 @@ if ($action == 'edit')
// Add a margin under toolbar ?
$style='';
-if ($action != 'preview' && $action != 'editcontent') $style=' margin-bottom: 5px;';
+if ($action != 'preview' && $action != 'editcontent' && $action != 'editsource') $style=' margin-bottom: 5px;';
//var_dump($objectpage);exit;
print '
@@ -463,12 +464,12 @@ if ($action == 'updatemeta')
if (! $result) setEventMessages('Failed to write file '.$filealias, null, 'errors');
- // Now create the .tpl file (duplicate code with actions updatecontent but we need this to save new header)
+ // Now create the .tpl file (duplicate code with actions updatesource or updatecontent but we need this to save new header)
dol_syslog("We regenerate the tpl page filetpl=".$filetpl);
dol_delete_file($filetpl);
@@ -463,12 +464,12 @@ if ($action == 'updatemeta')
dol_syslog("We regenerate the tpl page filetpl=".$filetpl);
dol_delete_file($filetpl);
- // TODO Same code than into updatecontent
+ // TODO Same code than into updatesource updatecontent
$tplcontent ='';
$tplcontent.= "fetch(0, $website);